@@ -1,5 +1,5 @@
 from unittest import TestCase
-from random import choice
+from random import choice, randint
 from os import remove
 
 from tinydb.database import Document
@@ -86,6 +86,42 @@ class TestData(TestCase):
         with self.assertRaises(KeyError):
             base.create({'something': 0})
 
+    def testSix(self):
+        """ tests purgeing of a table """
+        base = DatabaseBase(self.fileName, 'thing2')
+        for e in range(0, randint(25, 50)):
+            base.create({'title': 'foobar'})
+
+        self.assertFalse(len(base.readAll()) == 0)
+        base.clear()
+        self.assertTrue(len(base.readAll()) == 0)
+
+    def testSeven(self):
+        """ tests exists in a table """
+
+        
+        base = DatabaseBase(self.fileName, 'thing2')
+        title = f'bob-{randint(5000, 6000)}'
+        base.create({'title': title})
+
+        self.assertTrue(
+            base.exists('title', title)
+        )
+
+        title2 = f'bob-{randint(6000, 7000)}'
+        self.assertFalse(
+            base.exists('title', title2)
+        )
+
+    def testEight(self):
+        base = DatabaseBase(self.fileName, 'thing2')
+        self.assertIsInstance(
+            base.now_ts(),
+            float
+        )
+        
+
+
     def tearDown(self):
         try:
             remove(self.fileName)
